==> node-v19.6.1.tar.xz: node-v19.6.1/test/parallel/test-http-parser-free.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';
require('../common');
const assert = require('assert');
const http = require('http');
const Countdown = require('../common/countdown');
const N = 100;

const server = http.createServer(function(req, res) {
  res.end('Hello');
});

const countdown = new Countdown(N, () => server.close());

server.listen(0, function() {
  http.globalAgent.maxSockets = 1;
  let parser;
  for (let i = 0; i < N; ++i) {
    (function makeRequest(i) {
      const req = http.get({ port: server.address().port }, function(res) {
        if (!parser) {
          parser = req.parser;
        } else {
          assert.strictEqual(req.parser, parser);
        }

        countdown.dec();
        res.resume();
      });
    })(i);
  }
});

==> node-v25.4.0.tar.xz: node-v25.4.0/test/parallel/test-http-parser-free.js <==
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';
const common = require('../common');
const assert = require('assert');
const http = require('http');
const Countdown = require('../common/countdown');
const N = 100;

const server = http.createServer(function(req, res) {
  res.end('Hello');
});

const countdown = new Countdown(N, () => server.close());

server.listen(0, common.mustCall(() => {
  http.globalAgent.maxSockets = 1;
  let parser;
  for (let i = 0; i < N; ++i) {
    (function makeRequest(i) {
      const req = http.get({ port: server.address().port }, common.mustCall((res) => {
        if (!parser) {
          parser = req.parser;
        } else {
          assert.strictEqual(req.parser, parser);
        }

        countdown.dec();
        res.resume();
      }));
    })(i);
  }
}));
